(function(){
    /* ecom.wise.global 定义了一些全局的函数*/
    window.ecom.wise.global = {
        /** 此后，所有的脚本，都应该放在 run 中运行
         *  example:
         *  ecom.wise.global.run(function(win, doc, wise, global){
         *      //Do something.
         * });
         * 好处是，1、强制保证所有的函数都在某个闭包内；2、可以强制保证所有的函数都在 ready 后执行；3、统一的 try ... catch ... 及时报警；
         */
        run: function(func) {
            try {
                func(window, document, window.ecom.wise, window.ecom.wise.global);
            }catch (error) {
                this.handleError(error);
            }
        },

        /* 最底层用来发日志的函数，函数为什么要写成这样见：http://git.baidu.com/yangfan12/aspfe/snippets/47*/
        request: function(url) {
            if( url ){
                var timeStamp = new Date().getTime();
                var img = new Image();
                /* 添加随机字符串，避免被 cache 住。*/
                url += '&rand=' + ( timeStamp + Math.random() );
                window.ecom.wise.global['--IMAGE' + timeStamp] = img;
                img.onload = img.onerror = img.onabort = function(){
                    img.onload = img.onerror = img.onabort = null;
                    window.ecom.wise.global['--IMAGE' + timeStamp] = null;
                    img = null;
                };
                img.src = url;
            }
        },

        /* 对 request 的一次封装，用来向任意服务器发日志*/
        log : function(baseUrl, data){
            var params = window.ecom.wise.PARAMS;
            var dataArray = [];
            /*将PARAMS对象进行浅拷贝*/
            for(var key in params){
                if(params.hasOwnProperty(key)){
                    dataArray.push( encodeURIComponent(key) + "=" + encodeURIComponent(params[key]) );
                }
            }
            for(var key in data){
                if(data.hasOwnProperty(key)){
                    dataArray.push( encodeURIComponent(key) + "=" + encodeURIComponent(data[key]) );
                }
            }
            this.request( baseUrl + '?' + dataArray.join('&') );
        },

        getLogUrl : function(baseUrl, data){
            var params = window.ecom.wise.PARAMS;
            var dataArray = [];
            /*将PARAMS对象进行浅拷贝*/
            for(var key in params){
                if(params.hasOwnProperty(key)){
                    dataArray.push( encodeURIComponent(key) + "=" + encodeURIComponent(params[key]) );
                }
            }
            for(var key in data){
                dataArray.push( encodeURIComponent(key) + "=" + encodeURIComponent(data[key]) );
            }
            return  baseUrl + '?' + dataArray.join('&');
        },


        /* 对 log 的一次封装，用来向 fclick 发日志， 强制规范了 fclick 必须有的 tag和type, data为object对象。*/
        fclick: function(tag, type, data){
            data = data || {};
            data.type = window.ecom.wise.fclickType[type] || '';
            var fclickUrl = "http://fclick.baidu.com/w.gif";
            data.tag = tag;
            /*必选字段eid,baiduid,query,searchid,osid,bwsid,sourceid,rank,mt,xpath,type,tag*/
            var params = {
                /**广告级必选字段sourceid,rank,mt,xpath,type,tag
                  * 默认设置广告级必选字段值为空
                  */
                'sourceid': '',
                'rank': '',
                'mt': '',
                'xpath': '',
                'type': '',
                'tag': ''
            };
            for(var key in data){
                if(data.hasOwnProperty(key)){
                   params[key] = data[key];
                }
            }
            this.log( fclickUrl, params );
        },

        /** 对 fclick 的一次封装，用来向 fclick 发日志， 强制规范了 fclick 必须有的 tag和type, $dom为dom对象。
         *  @param {Object} data 表示object对象
         */
        adFclick: function(tag, $dom, data,type){
            var attrVal = $dom.getAttribute('data-fclick') || '{}';
            var params = eval('(' + attrVal + ')');
            for(var key in data){
                if(data.hasOwnProperty(key)){
                    params[key] = data[key];
                }
            }
            this.fclick(tag, type, params);
        },

        /**
          * 获取节点路径,用-连接
          * param {NodeList} leafNode 表示当前节点对象
          * param {NodeList} containerNode 表示指定根节点对象
          */
        getXPath: function(leafNode, containerNode){
            var xpaths = [];
            var tagName, nodePos, node, nodeInfo;
            while(leafNode && leafNode !== containerNode){
                tagName = leafNode.tagName;
                nodePos = this.getNodePosition(leafNode);
                nodeInfo = nodePos == 1 ? tagName : tagName + nodePos;
                xpaths.unshift(nodeInfo.toLowerCase());
                leafNode = leafNode.parentNode;
            }
            return xpaths.join('-');
        },

        /**
         * 获取节点位置
         * param {NodeList} node 表示节点对象
         * return {String} nodePos 表示节点名
         */
        getNodePosition: function(node){
            var nodePos = 0;
            var tagName = node.tagName;
            while(node){
                if(node.tagName === tagName){
                    nodePos++;
                }
                node = node.previousSibling;
            }
            return nodePos;
        },

        /* 全局的捕获异常的函数，想 fclick 发日志*/
        handleError: function(error) {
            var errorInfo = {
                url: window.location.href,
                message: error.message,
                datetime: (new Date()).getTime(),
                stack: error.stack
            };
            this.fclick('wise-js-error', 'OTHER', errorInfo);
        },

        /* 通用的不跳转计费的函数，其实觉得函数名可以该成 charge*/ 
        chargingRequest: function(url) {
            if (window.ecom.wise.ck) {
                var chargingUrl = window.ecom.wise.ck.addCkOnUrl(url);
                this.request(chargingUrl);
            }else {
                this.request(url);
            }
        }

    };
})();
/*ck*/
window.ecom.wise.Ck = (function() {
    var deviceIsIOS, 
    uniqueInstance, 
    bd, 
    touchStartTime, 
    touchEndTime, 
    pressTime, 
    touchX, 
    touchY, 
    isStartScroll, 
    scrollLastY, 
    scrollStartY, 
    scrollStartTime, 
    scrollTotalTime, 
    scrollDirection, 
    scrollNum, 
    scrollTotalChange, 
    validDirection, 
    imTimeSign, 
    scrollBoundary = 10, 
    numReg = /\d+/; 

    function constructor() {
        bd = document.body;
        touchstartTime = 0;
        touchEndTime = 0;
        pressTime = 0;
        touchX = 0;
        touchY = 0;
        scrollLastY = 0;
        scrollStartY = 0;
        scrollStartTime = 0;
        scrollTotalTime = 0;
        scrollDirection = 'none';
        scrollNum = 0;
        scrollTotalChange = 0;
        validDirection = 'none';
        imTimeSign = window.ecom.wise.imTimeSign;
        if (numReg.test(imTimeSign)) {
            imTimeSign = parseInt(imTimeSign,10);
        }else {
            throw new Error('imTimeSign is not a number, imTimeSign value is ' + 　imTimeSign);
        }
        addListener();
        return {
            addCkOnUrl: addCkOnUrl,

            clearCount: clearCount,
        };
    }

    function addListener() {
        bd.addEventListener('touchstart', onTouchStart, true);
        bd.addEventListener('touchend', onTouchEnd, true);
        bd.addEventListener('touchmove', onTouchMove, true);
        window.addEventListener('scroll', onScrollEvent, true);
    }
    function onTouchStart(event) {
        var touch = event.touches.item(0);
        touchX = touch.pageX;
        touchY = touch.pageY;
        countScrollOnTouchStart();
        touchStartTime = getEventTime(event);
    }

    function onTouchEnd(event) {
        touchEndTime = getEventTime(event);
        pressTime = touchEndTime - touchStartTime;
    }

    function onTouchMove(event) {
        triggerScrollEventForIphone(event);
    }
    function triggerScrollEventForIphone(event) {
        onScrollEvent(event);
    }

    function onScrollEvent(event) {
        if (!isStartScroll) {
            isStartScroll = true;
            scrollStartY = window.scrollY;
        }

        var nowScrollY = window.scrollY;
        var scrollValue = Math.abs(nowScrollY - scrollLastY);
        var nowDirection = getScrollDirection(scrollLastY, nowScrollY) || scrollDirection;

        if (isValidScroll(scrollValue, nowDirection)) {
            scrollLastTime = getEventTime(event);
            if (validDirection == 'none') {
                validDirection = scrollDirection;
                scrollStartTime = getEventTime(event);
            }
            if (validDirection != scrollDirection) {
                scrollCount();
                scrollStartTime = getEventTime(event);
                validDirection = scrollDirection;
            }
        }

        scrollLastY = nowScrollY;
    }
    function countScrollOnTouchStart() {
        if (isStartScroll && validDirection != 'none') {
            scrollCount();
            scrollTotalChange = 0;
            isStartScroll = false;
            scrollDirection = 'none';
        }
    }
    function isValidScroll(scrollValue, nowDirection) {
        if (scrollDirection == 'none') {
            scrollDirection = nowDirection;
        }

        if (nowDirection != scrollDirection) {
            scrollDirection = nowDirection;
            scrollTotalChange = 0;
        }else {
            scrollTotalChange += scrollValue;
        }
        return scrollTotalChange > scrollBoundary;
    }
    function getScrollDirection(startY, nowY) {
        if (nowY > startY) {
            return 'up';
        }else if (nowY < startY) {
            return 'down';
        }else {
            return false;
        }
    }
    function scrollCount() {
        scrollNum++;
        scrollTotalTime += scrollLastTime - scrollStartTime;
        validDirection = 'none';
    }


    function getCkValue(url) {
        if (typeof url != 'string') {
            return false;
        }
        var checkCode = getCheckCode(url, imTimeSign, pressTime, touchX);
        if (checkCode !== false) {
        var ckValue = [checkCode, pressTime, touchX, touchY, scrollNum, scrollTotalTime].join('.');
        clearCount();
            return ckValue;
        }else {
            return false;
        }
    }


    function addCkOnUrl(url) {
        var ckValue = getCkValue(url),
            ckReg = /&ck=[\w.]*/;
        if (ckValue === false) {
            return url;
        }
        if (url.indexOf('&ck=') == -1) {
            url += '&ck=' + ckValue;
        } else {
            url = url.replace(ckReg, '&ck=' + ckValue);
        }
        return url;
    }
    
    function clearCount() {
        scrollNum = 0;
        scrollTotalTime = 0;
    }

    function getCheckCode(href,imTimeSign,pressTime,touchX) {
        var urlSearch,
            urlReg = /\?url\=([^\.]+)\./,
            checkCode = 0;
        if (urlSearch = urlReg.exec(href)) {
            var num = (((pressTime * imTimeSign) % 99) + 9);
            for (var x = 0; x < num; ++x) {
                checkCode += urlSearch[1].charCodeAt((touchX * x) % urlSearch[1].length);
            }
            return checkCode;
        }
        return false;
    }
    function getEventTime(event) {
        if (event.timeStamp != 0) {
            return event.timeStamp;
        }else {
            var date = new Date();
            return date.getTime();
        }
    }

    return {
        getInstance: function()
        {
            if (!uniqueInstance) {
                uniqueInstance = constructor();
            }
            return uniqueInstance;
        }
    };
});
window.ecom.wise.global.run(function(){
    window.ecom.wise.ck = window.ecom.wise.Ck().getInstance();
});

window.ecom.wise.global.run(function() {
    var layers = document.querySelectorAll('.content');

    for (var i = layers.length - 1; i >= 0; i--) {
        layers[i].addEventListener('click', function(event) {
            addCk(event.target, layers[i]);
        }, true);
    }


    function addCk(dom,layer) {
        var currentDom = dom;
        while (currentDom != null && currentDom.tagName != 'A' && currentDom != layer) {
            currentDom = currentDom.parentNode;
        }
        if (currentDom == null) {
            return false;
        }
        if (currentDom.tagName == 'A' && currentDom.href !== '') {
            currentDom.href = window.ecom.wise.ck.addCkOnUrl(currentDom.href);
        }
    };
});
