/***************************************************************************
 * 
 * Copyright (c) 2014 Baidu.com, Inc. All Rights Reserved
 * 
 **************************************************************************/
 
 
 
/**
 * @file js/global.js
 * @author zhongligang01(zhongligang01@baidu.com)
 * @date 2014-09-05 22:51:46
 * @brief 
 *  
 **/

//* {{{ ec_global
(function () {
    window.ecom = window.ecom || {};
    ecom.wise = ecom.wise || {};

    ecom.wise.global = {
        run: function (func) {
            try {
                func(window, document, ecom.wise, ecom.wise.global);
            } catch (error) {
                this.handleError(error);
            }
        },

        // 最底层用来发日志的函数，函数为什么要写成这样见：http://git.baidu.com/yangfan12/aspfe/snippets/47
        request: function(url) {
            if (url) {
                var id = +new Date() + Math.random();
                var img = new Image();
                url += '&' + id;
                ecom.wise.global['--IMAGE' + id] = img;
                img.onload = img.onerror = img.onabort = function() {
                    img.onload = img.onerror = img.onabort = null;
                    ecom.wise.global['--IMAGE' + id] = null;
                    img = null;
                };
                img.src = url;
            }
        },

        // 对 request 的一次封装，用来向任意服务器发日志
        log: function (baseUrl, data) {
            this.request(this.getLogUrl(baseUrl, data));
        },

        getLogUrl: function (baseUrl, data) {
            var params = ecom.wise.PARAMS;
            var dataArray = [];
            for (var key in params) {
                if (params.hasOwnProperty(key)) {
                    dataArray.push(encodeURIComponent(key) + "=" + encodeURIComponent(params[key]));
                }
            }

            for (var key in data) {
                if (data.hasOwnProperty(key)) {
                    dataArray.push(encodeURIComponent(key) + "=" + encodeURIComponent(data[key]));
                }
            }
            return baseUrl + '?' + dataArray.join('&');
        },

        // 对 log 的一次封装，用来向 fclick 发日志， 强制规范了 fclick 必须有的 tag和type, data为object对象。
        fclick: function (tag, type, data) {
            var fclickUrl = "http://fclick.baidu.com/w.gif";
            // 必选字段eid,baiduid,query,searchid,osid,bwsid,sourceid,rank,mt,xpath,type,tag
            var params = {
                /**广告级必选字段sourceid,rank,mt,xpath,type,tag
                  * 默认设置广告级必选字段值为空
                  */
                'sourceid': '',
                'rank': '',
                'mt': '',
                'xpath': '',
                'type': '',
                'tag': ''
            };

            data = data || {};
            data.type = ecom.wise.fclickType[type] || '';
            data.tag = tag;
            for (var key in data) {
                if (data.hasOwnProperty(key)) {
                   params[key] = data[key];
                }
            }
            this.log(fclickUrl, params);
        },

        // 对 fclick 的一次封装，用来向 fclick 发日志， 强制规范了 fclick 必须有的 tag和type, $dom为dom对象。
        // @param {Object} data 表示object对象
        adFclick: function (tag, $dom, data, type) {
            var attrVal = $dom.getAttribute('data-fclick') || '{}';
            var params = eval('(' + attrVal + ')');
            for (var key in data) {
                if (data.hasOwnProperty(key)) {
                    params[key] = data[key];
                }
            }
            this.fclick(tag, type, params);
        },

        // 获取节点路径,用-连接
        // param {NodeList} leafNode 表示当前节点对象
        // param {NodeList} containerNode 表示指定根节点对象
        getXPath: function (leafNode, containerNode) {
            var xpaths = [];
            var tagName, nodePos, node, nodeInfo;
            while (leafNode && leafNode !== containerNode) {
                tagName = leafNode.tagName;
                nodePos = this.getNodePosition(leafNode);
                nodeInfo = nodePos == 1 ? tagName : tagName + nodePos;
                xpaths.unshift(nodeInfo.toLowerCase());
                leafNode = leafNode.parentNode;
            }

            return xpaths.join('-');
        },

        // 获取节点位置
        // param {NodeList} node 表示节点对象
        // return {String} nodePos 表示节点名
        getNodePosition: function (node) {
            var nodePos = 0;
            var tagName = node.tagName;
            while (node) {
                if (node.tagName === tagName) {
                    nodePos++;
                }
                node = node.previousSibling;
            }
            return nodePos;
        },

        // 全局的捕获异常的函数，想 fclick 发日志
        handleError: function(error) {
            var errorInfo = {
                url: location.href,
                message: error.message,
                datetime: +new Date(),
                stack: error.stack
            };
            this.fclick('wise-js-error', 'OTHER', errorInfo);
        },

        // 通用的不跳转计费的函数，其实觉得函数名可以该成 charge
        chargingRequest: function (url) {
            if (ecom.wise.ck) {
                var chargingUrl = ecom.wise.ck.addCkOnUrl(url);
                this.request(chargingUrl);
            } else {
                this.request(url);
            }
        }
    };

    ecom.wise.Ck = (function () {
        var deviceIsIOS, 
        uniqueInstance, 
        bd, 
        touchStartTime, 
        touchEndTime, 
        pressTime, 
        touchX, 
        touchY, 
        isStartScroll, 
        scrollLastY, 
        scrollStartY, 
        scrollStartTime, 
        scrollTotalTime, 
        scrollDirection, 
        scrollNum, 
        scrollTotalChange, 
        validDirection, 
        imTimeSign, 
        scrollBoundary = 10, 
        numReg = /\d+/; 

        function constructor() {
            bd = document.body;
            touchstartTime = 0;
            touchEndTime = 0;
            pressTime = 0;
            touchX = 0;
            touchY = 0;
            scrollLastY = 0;
            scrollStartY = 0;
            scrollStartTime = 0;
            scrollTotalTime = 0;
            scrollDirection = 'none';
            scrollNum = 0;
            scrollTotalChange = 0;
            validDirection = 'none';
            imTimeSign = window.ecom.wise.imTimeSign;
            if (numReg.test(imTimeSign)) {
                imTimeSign = parseInt(imTimeSign,10);
            }else {
                throw new Error('imTimeSign is not a number, imTimeSign value is ' + 　imTimeSign);
            }
            addListener();
            return {
                addCkOnUrl: addCkOnUrl,

                clearCount: clearCount,
            };
        }

        function addListener() {
            bd.addEventListener('touchstart', onTouchStart, true);
            bd.addEventListener('touchend', onTouchEnd, true);
            bd.addEventListener('touchmove', onTouchMove, true);
            window.addEventListener('scroll', onScrollEvent, true);
        }
        function onTouchStart(event) {
            var touch = event.touches.item(0);
            touchX = touch.pageX;
            touchY = touch.pageY;
            countScrollOnTouchStart();
            touchStartTime = getEventTime(event);
        }

        function onTouchEnd(event) {
            touchEndTime = getEventTime(event);
            pressTime = touchEndTime - touchStartTime;
        }

        function onTouchMove(event) {
            triggerScrollEventForIphone(event);
        }
        function triggerScrollEventForIphone(event) {
            onScrollEvent(event);
        }

        function onScrollEvent(event) {
            if (!isStartScroll) {
                isStartScroll = true;
                scrollStartY = window.scrollY;
            }

            var nowScrollY = window.scrollY;
            var scrollValue = Math.abs(nowScrollY - scrollLastY);
            var nowDirection = getScrollDirection(scrollLastY, nowScrollY) || scrollDirection;

            if (isValidScroll(scrollValue, nowDirection)) {
                scrollLastTime = getEventTime(event);
                if (validDirection == 'none') {
                    validDirection = scrollDirection;
                    scrollStartTime = getEventTime(event);
                }
                if (validDirection != scrollDirection) {
                    scrollCount();
                    scrollStartTime = getEventTime(event);
                    validDirection = scrollDirection;
                }
            }

            scrollLastY = nowScrollY;
        }
        function countScrollOnTouchStart() {
            if (isStartScroll && validDirection != 'none') {
                scrollCount();
                scrollTotalChange = 0;
                isStartScroll = false;
                scrollDirection = 'none';
            }
        }
        function isValidScroll(scrollValue, nowDirection) {
            if (scrollDirection == 'none') {
                scrollDirection = nowDirection;
            }

            if (nowDirection != scrollDirection) {
                scrollDirection = nowDirection;
                scrollTotalChange = 0;
            }else {
                scrollTotalChange += scrollValue;
            }
            return scrollTotalChange > scrollBoundary;
        }
        function getScrollDirection(startY, nowY) {
            if (nowY > startY) {
                return 'up';
            }else if (nowY < startY) {
                return 'down';
            }else {
                return false;
            }
        }
        function scrollCount() {
            scrollNum++;
            scrollTotalTime += scrollLastTime - scrollStartTime;
            validDirection = 'none';
        }


        function getCkValue(url) {
            if (typeof url != 'string') {
                return false;
            }
            var checkCode = getCheckCode(url, imTimeSign, pressTime, touchX);
            if (checkCode !== false) {
            var ckValue = [checkCode, pressTime, touchX, touchY, scrollNum, scrollTotalTime].join('.');
            clearCount();
                return ckValue;
            }else {
                return false;
            }
        }


        function addCkOnUrl(url) {
            var ckValue = getCkValue(url),
                ckReg = /&ck=[\w.]*/;
            if (ckValue === false) {
                return url;
            }
            if (url.indexOf('&ck=') == -1) {
                url += '&ck=' + ckValue;
            } else {
                url = url.replace(ckReg, '&ck=' + ckValue);
            }
            return url;
        }
        
        function clearCount() {
            scrollNum = 0;
            scrollTotalTime = 0;
        }

        function getCheckCode(href,imTimeSign,pressTime,touchX) {
            var urlSearch,
                urlReg = /\?url\=([^\.]+)\./,
                checkCode = 0;
            if (urlSearch = urlReg.exec(href)) {
                var num = (((pressTime * imTimeSign) % 99) + 9);
                for (var x = 0; x < num; ++x) {
                    checkCode += urlSearch[1].charCodeAt((touchX * x) % urlSearch[1].length);
                }
                return checkCode;
            }
            return false;
        }
        function getEventTime(event) {
            if (event.timeStamp != 0) {
                return event.timeStamp;
            }else {
                var date = new Date();
                return date.getTime();
            }
        }

        return {
            getInstance: function () {
                if (!uniqueInstance) {
                    uniqueInstance = constructor();
                }
                return uniqueInstance;
            }
        };
    });
})();

$(function () {
    ecom.wise.ck = ecom.wise.Ck().getInstance();
});

$(function () {
    var layers = document.querySelectorAll('.content');
    var addCk = function (dom,layer) {
        var currentDom = dom;
        while (currentDom != null && currentDom.tagName != 'A' && currentDom != layer) {
            currentDom = currentDom.parentNode;
        }
        if (currentDom == null) {
            return false;
        }
        if (currentDom.tagName == 'A' && currentDom.href !== '') {
            currentDom.href = ecom.wise.ck.addCkOnUrl(currentDom.href);
        }
    };

    for (var i = layers.length - 1; i >= 0; i--) {
        layers[i].addEventListener('click', function(event) {
            addCk(event.target, layers[i]);
        }, true);
    }
});
// End of ec_global }}} */

//* {{{ stuff
$(function () {
    var Zt = {
        winboxArr: [],
        now: function () {
            return +new Date();
        }
    };

    (function (window, Z, $) {
        Z.closeWin = function (fn) {
            //堆栈中取出所有win, 循环关闭.
            var winboxArr = this.winboxArr || {};
            var isHas = 0;
            for (var win in winboxArr) {
                isHas = 1;
                winboxArr[win].closeWin();
            }
            if (fn) {
                fn();
            }
            $('#hideForLoginBox').append(Z.loginBox);
        };

        window.closePop = function(){
            Z.closeWin();
        }
        Z.showWin = function (opts) {
            //支持直接调用和new
            var me = this;
            //若直接调用, 只显示一次
            if (!(me instanceof Z.showWin)) {
                opts.showOnce = true;
                var newWin = new me.showWin(opts);
                newWin.initWin(true);
                return;
            }

            if (opts == undefined) {
                opts = {};
            } else if (typeof opts == 'string') {
                opts = {
                    htmlStr: opts
                };
            }

            var showOnce = opts.showOnce || false;

            me.onWinBoxShowed = opts.onWinBoxShowed || function () {};
            me.html = opts.htmlStr || '';

            me.initMask = function () {
                if (me.winmask) {
                    me.winmask.remove();
                }
                var maskWidth = '100%';
                var maskHeight = $(document).height()+'px';

                var maskArr = ['<div style="width:', maskWidth, ';height:', maskHeight, ';position:absolute;z-index: 998;', 'background:', opts.maskColor || '#FFF', ';opacity:',opts.opacity ||'0.6' ,';top:0;left:0;" class="__mask winbox-mask"></div>'];

                me.winmask = $(maskArr.join(''));
                $('body').append(me.winmask);
            };

            me.closeWin = function (callback) {
                if (me.timer) {
                    clearTimeout(me.timer);
                    me.timer = null;
                }
                if (showOnce) {
                    me.winbox.remove();
                    me.winmask.remove();
                    //删除win
                    delete Z.winboxArr[me.timespam];
                } else {
                    me.winbox.hide();
                    me.winmask.hide();
                }
                ecomdx.setPopShow(false);//客户端接口
                if (callback) callback();
            };

            me.initWin = function (show) {
                var html = me.html;
                if (typeof html == 'string' && !(/<|>/.test(html))) {
                    me.winbox = $(['<div>', html, '</div>'].join(''));
                } else {
                    me.winbox = $(html);
                }
                if (showOnce) {
                    //这个是为了兼容未添加new方法前,旧代码的Z.winbox调用
                    Z.winbox = me.winbox;
                }
                me.winmask = $('');
                me.winbox.hide();
                $('body').append(me.winbox);
                me.winbox.click(function (e) {
                    if ($(e.target).hasClass('close')) {
                        me.closeWin(opts.callback);
                        e.preventDefault();
                    }
                });
                if (show) {
                    me.show();
                }
            };

            me.show = function () {
                if (!opts.noMask) {
                    me.initMask();
                }
                me.winbox.show();
                me.initPos();
                ecomdx.setPopShow(true);//客户端接口
                $('.__mask').on('touchmove', function(e){ 
                    //prevent native touch activity like scrolling
                    e.preventDefault(); 
    }           );
                me.onWinBoxShowed.call(this);
                if (opts.autohide) {
                    me.timer = setTimeout(function () {
                        me.closeWin();
                    }, opts.hidetime || 0);
                }

            };
            me.initPos = function () {
                if (opts.offset) {
                    me.winbox.css(opts.offset);
                    me.winbox.css({
                        position: 'fixed',
                        zIndex: '999'
                    });
                    return;
                }
                var boxWidth = me.winbox.width();
                var boxHeight = me.winbox.height();

                me.winbox.css({
                    position: 'fixed',
                    top: '50%',
                    left: '50%',
                    margin: '-' + boxHeight / 2 + 'px 0 0 -' + boxWidth / 2 + 'px',
                    zIndex: '999'
                });
            };
            
            var timespam = new Date().getTime();
            me.timespam = timespam;
            Z.winboxArr[timespam] = me;
            return me;
        };

        Z.dail = function(phoneNum,name,rcv,logUrl,detailUrl){
            var html =[
                '<div class="wbox">'
                ,'	<div class="wCon">'
                ,'		<div class="wA">'
                ,'			<p>'
                ,'				<span class="tel">',phoneNum,'</span>'
                ,'			</p>'
                ,'			<p class="pop">'
                ,'				<span class="add">',name || '','</span>'
                ,'			</p>'
                ,'		</div>'
                ,'		<div class="wB">'
                ,'			<a href="#">拨号</a>'
                ,'		</div>'
                ,'	</div>'
                ,'</div>'
            ];

            Zt.showWin({
                htmlStr: html.join('')
                ,maskColor : '#828282'
                ,onWinBoxShowed: function(){
                    var me = this;
                    $('.__mask').on('click',function(e){
                        me.closeWin();
                    });
                    $('.wB').on('click',function(e){
                        e.preventDefault();
                        
                        ecomdx.call(phoneNum,logUrl, name, detailUrl);
                    })
                }
            });
        };
    })(window, Zt, $);

    window.Zt = Zt;
});
// End of stuff }}} */

//* {{{ mockClient
$(function () {
    if ("undefined" == typeof ecomdx) {
        window.ecomdx = {};
        window.ecomdx.jump = function(url, title){
             window.open(url);
        }
        window.ecomdx.call = function(phone, url) {
            window.open("tel://" + phone);
        }
        window.ecomdx.setPopShow = function(isShow){
        }
        window.ecomdx.updateFavorite = function (hasFav) {};
        window.ecomdx.enterShop = function(){}
    }
});
// End of mockClient }}} */

// 业务逻辑代码开始

//* {{{ search
$(function () {
    ecom.wise.js = ecom.wise.js || {};
    ecom.wise.lsJs = ecom.wise.lsJs || {};
    ecom.wise.css = ecom.wise.css || {};
    ecom.wise.succFlag = false;
    ecom.wise.adType = [];
    // fclick日志类型AD:广告级REQUEST:请求级OTHER:其它
    ecom.wise.fclickType = {
        'AD': 'ad',
        'REQUEST': 'request',
        'OTHER': 'other',
        'NATURE': 'nature',
    };

    $('.content').delegate('ul.tj-ul li','click',function(e){
        var li = $(this)
        var callRcv = li.attr('call-rcv');//电话计费链接
        var name = li.attr('data-name');
        var phone = li.attr('data-phone');
        var detailUrl = li.attr('data-url');
        var type = 'NATURE';
        var fclickTag = '';
        var id = li.attr('data-id');
        if (li.hasClass('ec_ad')){
            type = 'AD';
        }
        var rank =  li.index() + 1;
        
        var $target = $(e.target);

        if ($target.closest('.conB').length) {  // 右侧箭头点击
            detailUrl = window.ecom.wise.ck.addCkOnUrl(detailUrl);

            ecomdx.enterShop(name, phone, detailUrl);
    
            fclickTag = 'dx-list-detail-click';
            ecomdx.jump(detailUrl,name);
        } else if ($target.closest('.collect-btn').length) {    // 收藏按钮点击

            if (ecom.wise.collect) {
                ecom.wise.collect.handleClickEvent($target, id, li);
            }

        } else { // 左侧大区域点击
            var fclickUrl = 'http://fclick.baidu.com/w.gif';
            var params = {};
            params.rank =rank;
            params.phone = phone;
            params.date = new Date().getTime();
            params.tag = 'dx-list-call';
            params.calltype = type;
            var logUrl = window.ecom.wise.global.getLogUrl(fclickUrl,params);
            if (callRcv) {
                ecom.wise.global.chargingRequest(callRcv);
            }

            Zt.dail(
                phone,
                name,
                callRcv,
                logUrl,
                detailUrl
            );
            fclickTag = 'dx-list-direct-click';
        }
        ecom.wise.global.adFclick(fclickTag, this,{'phone' : phone,'rank':rank}, type);
    });

    $('ul.tj-ul').delegate('li','touchstart',function(e){
        var li = $(this);
        var $target = $(e.target);
        $('.bg').removeClass('bg');
        $('.bgw').removeClass('bgw');
        
        if ($target.closest('.conB').length) {  // right
            $target.closest('li').find('.r').eq(0).addClass('bg');
            // $target.closest('li').find('.r .conC').addClass('bgw');
            
        } else if ($target.closest('.collect-btn').length) {    // collect
            $target.closest('li').find('.collect-btn').addClass('bg');
            
        } else { // left
            li.addClass('bg');
            li.find('div.r').addClass('bgw');
            //li.find('.r.text').addClass('bg');
        }
    });

    $('ul.tj-ul').delegate('li','touchend',function(e){
        $('.bg').removeClass('bg');
        $('.bgw').removeClass('bgw');
    });

    $('ul.tj-ul').delegate('li','touchmove',function(e){
        $('.bg').removeClass('bg');
        $('.bgw').removeClass('bgw');
    });

    Zepto(function($){
    if (ecom.wise.chargeData) {
        var delayTime = Math.floor(Math.random()*3000 + 1000);;
        var chargeData = ecom.wise.chargeData;

        setTimeout(function(){
            $.get(chargeData.chargeUrl);
        },delayTime);

        var downLoadDom = $('<div class="appDownLoad">'
            + '<img src="'+chargeData.appIcon+'" width=32/>'
            + '<a href="'+chargeData.appUrl+'">下载app</a>'
            + '<span class="ad-close">关闭</span>'
            +'</div>');
        $('body').append(downLoadDom);

        $('.ad-close').on('click', function(){
            $('.appDownLoad').hide();
        })
    }
})

});
// End of search }}} */

//* {{{ loadMore
$(function () {
	var win_height = $(window).height(), //页面可视区域高度
		tag_point = 0,
		window_jq = $(window),
		body_jq = $(document.body),
		page_height = 0 ,
		scroll_top = 0;

    var more = function () {
        var me = $('.more');
        if (!me.length) {
            return;
        }
        var url = me.find('span').attr('rel');
        if (url.length < 3) {
            me.find('span').html('没有更多了！');
            can_flag = false;
            return;
        }
        $('.loading').show();
        $.get(url, function (msg) {
            if (msg) {
                $('ul.business-ul').append(msg.data.itemsHtml);
                $('.loading').hide();
                me.find('span').attr('rel', msg.data.nextPage);
                can_flag = true;
            }
        },'json');
    }

	var can_flag = true;
	window_jq.scroll(function () {
		page_height = body_jq.height(); //页面高度
		scroll_top = window_jq.scrollTop(); //滚动条top 
		trigger_point = (page_height - win_height - scroll_top)/win_height;
		if (trigger_point < 0.2) {
			if (!can_flag) {
				return;
			}
			can_flag = false;
            more();
		}
	});

    if ($('ul.business-ul li').length < 8) {
        more(); 
    }
});
// End of loadMore }}} */

//* {{{ collect
$(function () {
    window.pageEnterEditMode = function () {
        $(document.body).addClass('edit');
    };

    window.pageExitEditMode = function () {
        $(document.body).removeClass('edit');
    };

    (function (win, doc, $, undefined) {
        function transPre(){
            var S = document.createElement('div').style;
            var p = ['t','webkitT','MozT','msT','OT'];
            var v = 'ransform';
            var i = 0;
            var k;
            for(;i<p.length;i++){
                k = p[i] + v;
                if( k in S ){
                    return p[i];
                }
            }
            return false;
        }
        function transKey( v ){
            var v = v || 'ransform';
            var p = transPre();
            if( p === false ){
                return false;
            }
            return p + v;
        }
        function tranEndKey(){
            var k = transPre();
            if( k === false ){
                return false;
            }
            var a = {
                't'         : 'transitionend' ,
                'webkitT'   : 'webkitTransitionEnd',
                'MozT'      : 'transitionend',
                'msT'       : 'MSTransitionEnd',
                'OT'        : 'otransitionend'
            };
            return a[ k ] || false;
        }
        win.ecom = win.ecom || {};
        var wise = win.ecom.wise = win.ecom.wise || {};

        var C = win.ecom.wise.collect = {};
        var actionTypeMapping = {
            'v'         : 1,
            'poi'       : 2,
            'dianping'  : 3
        };
        var getActionType = function () {
            var action = wise.PARAMS.router.split('/')[1];
            return actionTypeMapping[action] || 1;
        };
        var getAjaxParam = function ($elem, $li, id) {
            var data = $li.attr('data-collect');
            if (data) {
                return eval('('+data+')');
            } else {
                return {};
            }
        };
        var scrollTop = function () {
            return doc.body.scrolTop || doc.documentElement.scrollTop;
        };
        var offsetTop = function ($elem) {
            var elem = $elem.get(0);
            if (!elem) {
                return 200;
            }
            if (elem.getBoundingClientRect) {
                return elem.getBoundingClientRect().top;
            } else {
                return $elem.offset().top - scrollTop();
            }
        };
        var drawPath = function ($elem) {
            var top = offsetTop($elem) - parseInt($elem.css('margin-top'), 10);
            ecom.wise.collect.heartDrawPath(top);
            
        };
        var addSuccess = function ($elem, json, $li) {
            if (!$elem.hasClass('on')) {
                $elem.addClass('on');
            }

            drawPath($elem);

            if (json.data && json.data.pk_id) {
                $elem.attr('data-pk-id', json.data.pk_id);
                window.ecomdx && ecomdx.updateFavorite && ecomdx.updateFavorite(json.data.hasFav);
            }
        };
        var removeSuccess = function ($elem, json, $li) {
            var $body = $(doc.body);
            if ($elem.hasClass('on')) {
                if ($body.hasClass('edit')) {   // in collect page
                    hideCollectionItem($li);
                } else { // in search page
                    $elem.removeClass('on');
                }
            }

            $elem.attr('data-pk-id', '');
            window.ecomdx && ecomdx.updateFavorite && ecomdx.updateFavorite(json.data.hasFav);
        };
        var hideCollectionItem = function ($li) {
            var tsKey = transKey('ransition');
            $li.css('position', 'relative');
            $li.css('left', '0');
            $li.css(tsKey, 'left 1s linear');

            // delay for transition
            setTimeout(function () {
                $li.css('left', '100%');
            }, 20);
            setTimeout(function () {
                $li.remove();
            }, 1100);
        };
        C.handleClickEvent = function ($elem, id, $li) {
            if ($elem.hasClass('collect-btn')) {
                $elem = $elem.find('.collect-heart');
            }
            var succFunc = function (json) {
                if (json.code) {
                    return alert(json.msg || ('请求错误，错误码：' + json.code));
                }
                // handle success
                if (action == 'add') {
                    addSuccess($elem, json, $li);
                } else {
                    removeSuccess($elem, json, $li);
                }
            };
            var failFunc = function (o, info) {
                alert('请求失败.' + (info || ''));
            };
            var ajaxParam = getAjaxParam($elem, $li, id);
            var action = 'add';
            if ($elem.hasClass('on')) { // 已经是选中状态，则是删除操作
                action = 'remove';
                ajaxParam.pk_id = $elem.attr('data-pk-id') || 0; // 根据主键删除
            }
            var ajaxOpt = {};
                ajaxOpt.type = 'POST';
                ajaxOpt.dataType = 'json';
                ajaxOpt.url = '/collect/' + action;
                ajaxOpt.data = ajaxParam;
                ajaxOpt.success = succFunc;
                ajaxOpt.error = failFunc;
            $.ajax(ajaxOpt);
        };

        C.heartDrawPath = function (y) {
            var $elem = $('<div class="collect-heart on"></div>');
                $elem.css('position', 'fixed');
                $elem.css('right', '69px');
                $elem.css('top', y + 'px');
            var tsKey = transKey('ransition');
                $elem.css(tsKey, 'top 1s linear, right 0.5s ease-out');
                
            $(doc.body).append($elem);

            setTimeout(function () {
                $elem.css('top', '-40px');
                $elem.css('right', '180px');
            }, 10);

            setTimeout(function () {
                $elem.css('right', '50px');
            }, 500);
            
            setTimeout(function () {
                $elem.remove();
            }, 1300);
        };
    })(window, document, $);
});
// End of collect }}} */

//* {{{ tuangou
$(function() {
    var currentPage = 1;
    var pageSize = 10;
    var noMore = false;
    var loading = false;

    var showNoMore = function () {
        $('#tgMore').html('没有更多了');
    }

    var showLoading= function () {
        $('#tgMore').html('正在加载...');
    }

    var revertLoading = function () {
        $('#tgMore').html('查看更多团购');
    }

    var moreCallback = function (data) {
        revertLoading();
        loading = false;
        if (data.status === 0 && data.data.count > 0) {
            $('#tgList').append($(data.data.html));
            if (data.data.count < pageSize) {
                noMore = true;
            }
        } else {
            noMore = true;
            showNoMore();
        }
    }

    $('#tgList li').live('click', function () {
        ecomdx.jump(this.getAttribute('data-url'), this.getAttribute('data-name'));
    });

    $('#tgMore').on('click', function () {
        var hiddens, els;
        if (loading) {
            return;
        }
        if (currentPage == 1) {
            hiddens = $('#tgList li.hidden');

            if (hiddens.size() > 0) {
                hiddens.removeClass('hidden');
                return;
            } else {
                els = $('#tgList li');
                if (els.size() < pageSize) {
                    noMore = true;
                    showNoMore();
                    return;
                }
            }
        }

        if (!noMore) {
            __tuangou_param.page = ++currentPage;
            showLoading();
            loading = true;
            $.get('/searchv3/tuangou', __tuangou_param, moreCallback, 'json');
        } else {
            showNoMore();
        }
    });

    var scrollMoreCallback = function (data) {
        loading = false;
        $('.tg-scroll-loading').hide();
        if (data.status === 0 && data.data.count > 0) {
            $('#tgList').append($(data.data.html));
            if (data.data.count < pageSize) {
                noMore = true;
            }
        } else {
            noMore = true;
        }
    };

    var scrollMore = function () {
        if (loading) {
            return;
        }
        if (noMore) {
            $('#tgScrollMore').find('span').html('没有更多了！');
            return;
        }
        $('.tg-scroll-loading').show();
        __tuangou_param.page = ++currentPage;
        loading = true;
        $.get('/searchv3/tuangou', __tuangou_param, scrollMoreCallback,'json');
    };

    var scrollMoreDetect = function () {
        var st = $(window).scrollTop(),
            wh = $(window).height(),
            off = $('#tgList li').last().offset();

        if (off.top < st + wh) {
            scrollMore();
        }
    };

    if ($('#tgScrollMore').size() > 0) {
        setInterval(scrollMoreDetect, 25);
    }
});
// End of tuangou }}} */

/* vim: set expandtab ts=4 sw=4 sts=4 tw=100: */
